//
//  MMIUtils.h
//
//
//  Created by Martin Redington on 6/16/05.
//  Copyright 2005 __MyCompanyName__. All rights reserved.
//

//
// Copyright 2005-2006 MildMannered Industries. All right reserved.
// 
//

/*! @header MMIUtils.h
@discussion Provider of static utility methods.
*/


#import <Cocoa/Cocoa.h>


#define APPLICATION_SUPPORT_DIR @"Application Support"
#define CACHES_DIR @"Caches"
#define LOGS_DIR @"Logs"


@class MMIError;


@interface MMIUtils (ApplicationSupportPaths)

+ (NSString *)appName;

/*!
@method applicationSupportDirForApp:error:
	@abstract Returns the path to the Application Support dir for the app, creating it if necessary.
	@discussion The Application Support dir should be located at ~/Library/Application Support/appName
                nil will be returned, and errPtr will be set if ~/Library or any of the other subdirectories is not readable and
                writable, or if it cannot be created.
	@param appName The name of the application. This should be non-nil
	@param errPtr The address of an error to set if there are any problems.
    @result The path to the Application Support dir for the app, or nil if there was an error.
 */
+ (NSString *) applicationSupportDirForApp:(NSString *) appName error:(MMIError **)errPtr;

+ (NSString *) applicationSupportDir:(MMIError **)errPtr;


/*!
@method cachesDirForApp:error:
     @abstract Returns the path to the Caches dir for the app, creating it if necessary.
     @discussion The Caches dir should be located at ~/Library/Caches/appName
     nil will be returned, and errPtr will be set if ~/Library or any of the other subdirectories is not readable and
     writable, or if it cannot be created.
     @param appName The name of the application. This should be non-nil
     @param errPtr The address of an error to set if there are any problems.
     @result The path to the Caches dir for the app, or nil if there was an error.
     */
+ (NSString *) cachesDirForApp:(NSString *) appName error:(MMIError **)errPtr;

+ (NSString *) cachesDir:(MMIError **)errPtr;

    
/*!
 @method logsDirForApp:error:
     @abstract Returns the path to the Logs dir for the app, creating it if necessary.
     @discussion The Logs dir should be located at ~/Library/Logs/appName
     nil will be returned, and errPtr will be set if ~/Library or any of the other subdirectories is not readable and
     writable, or if it cannot be created.
     @param appName The name of the application. This should be non-nil
     @param errPtr The address of an error to set if there are any problems.
     @result The path to the Caches dir for the app, or nil if there was an error.
     */
+ (NSString *) logsDirForApp:(NSString *) appName error:(MMIError **)errPtr;

+ (NSString *) logsDir:(MMIError **)errPtr;


/*!
@method checkDir:error:
	@abstract Returns YES if the directory path exists, or was created successfully, and is readable and writable.
	@discussion This will create the path if necessary. All directories except the final one must already exist. 
	@param dirPath The path to check
	@param errPtr The address of an error to set if there are any problems.
    @result YES if the path is OK, and NO otherwise.
 */
+ (BOOL) checkDir:(NSString *) dirPath error:(MMIError **)errPtr;
// + (BOOL) checkPathForWriting:(NSString *) path error:(MMIError **)errPtr;

@end
